@@ -27,6 +27,8 @@ from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
 from PyFin.Math.Accumulators.StatelessAccumulators import PositivePart
 from PyFin.Math.Accumulators.StatelessAccumulators import NegativePart
 from PyFin.Math.Accumulators.StatelessAccumulators import Max
+from PyFin.Math.Accumulators.StatelessAccumulators import Maximum
+from PyFin.Math.Accumulators.StatelessAccumulators import Min
 from PyFin.Math.Accumulators.StatelessAccumulators import Minimum
 from PyFin.Math.Accumulators.StatelessAccumulators import Sum
 from PyFin.Math.Accumulators.StatelessAccumulators import Average
@@ -58,7 +60,7 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelationMatrix
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
-from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinimum
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingMin
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingQuantile
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAllTrue
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAnyTrue
@@ -78,6 +80,7 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingAroon
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingBias
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAutoCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingLogReturn
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingResidue
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAlphaBeta
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingDrawDown
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverageDrawdown
@@ -104,6 +107,8 @@ __all__ = ["Exp",
            "PositivePart",
            "NegativePart",
            "Max",
+           "Maximum",
+           "Min",
            "Minimum",
            "Sum",
            "TruncatedValueHolder",
@@ -128,13 +133,14 @@ __all__ = ["Exp",
            "MovingCorrelation",
            "MovingCorrelationMatrix",
            "MovingMax",
-           "MovingMinimum",
+           "MovingMin",
            "MovingQuantile",
            "MovingAllTrue",
            "MovingAnyTrue",
            "MovingVariance",
            "MovingStandardDeviation",
            "MovingLogReturn",
+           "MovingResidue",
            "MovingAlphaBeta",
            "MovingDrawDown",
            "MovingAverageDrawdown",
